#include <stdio.h>
#include <string.h>
#include <stdlib.h>

typedef struct {
    char* a;
    char* b;
} repl;

/* single word replacements */
repl words [] = {
    {"amar",  "earth"},
    {"menel", "sky"},
    {"nen",   "water"},
    {"naur",  "fire"},
    {"benn",  "man"},
    {"bess",  "woman"},
    {"mad",   "eat"},
    {"sog",   "drink"},
    {"beleg", "big"},
    {"aur",   "day"},
    {"du",    "night"}
};

/* phrase replacements */
repl phrases [] = {
    {"nen menel", "rain"},
    {"nen amar",  "sea"},
    {"nen lunt",  "boat"},
    {"nen naur",  "alcohol"},
    {"aur o du",  "evening"},
    {"du o aur",  "morning"}
};

/* all the separating character between words */
char separators [] = {' ', ',', '.', '\n'};

/* scooch some number of spots over left side of location */
void scooch(char* location, int scooches) {
    int i;
    char* spot = location;

    /* for each letter in the new string (including \0) */
    for (i = 0; i <= (strlen(location) - scooches); i++) {
        /* move the character on top of our place */
        *spot = location[scooches + i];
        spot++;
    }
}

/* shimmy some characters into a location, moving rest to right */
void shimmy(char* location, char* rest) {
    int i;

    /* make room for the new characters */
    for (i = strlen(location); i >= 0; i--) {
        location[i + strlen(rest)] = location[i];
    }

    /* put the rest into spot now */
    for (i = 0; i < strlen(rest); i++) {
        location[i] = rest[i];
    }
}

/* perform a replacement on a string in place */
void replace(repl change, char* input) {
    char *aptr, *bptr, *cut;
    int scooched = 0, i;

    /* for each word separator character */
    for (i = 0; i < (sizeof(separators) / sizeof(char)); i++) {
        /* find first instance of a in the string with this after it */
        char temp[32];
        sprintf(temp, "%s%c", change.a, separators[i]);
        cut = strstr(input, temp);

        /* if it wasn't NULL, break out, we have one */
        if (cut) break;
    }

    /* if we have no cut, return */
    if (!cut) return;

    /* for each character a */
    bptr = change.b;
    for (aptr = change.a; *aptr; aptr++, bptr++, cut++) {
        /* if we are out of b's, then just scooch up the string over rest of a */
        if (*bptr == '\0') {
            scooch(cut, strlen(aptr));
            scooched = 1;
            break;
        } else {
            /* replace one character */
            *cut = *bptr;
        }
    }

    /* if there is b left, we must shimmy b chars into string */
    if (*bptr && !scooched) {
        shimmy(cut, bptr);
    }

    /* recursively do all this again in case there are more instances */
    replace(change, input);
}


int main() {
    int i;

    /* read the input string - make it a huge buffer so we don't need to deal
     * with it being too small - only OK for programming contests ;) */
    char* input = malloc(5000);
    size_t size = 5000;
    getline(&input, &size, stdin);

    /* perform each phrase replacement first */
    for (i = 0; i < (sizeof(phrases) / sizeof(repl)); i++) {
        replace(phrases[i], input);
    }

    /* now do single words */
    for (i = 0; i < (sizeof(words) / sizeof(repl)); i++) {
        replace(words[i], input);
    }

    /* print the modified string */
    printf("%s", input);

    free(input);
    return 0;
}

