#include <stdio.h>
#include <string.h>
#include <stdlib.h>

/* a linked list of hobbits */
typedef struct tag_node {
    int time;
    struct tag_node* next;
} node;

/* add hobbit to a list */
void add(node** head, int time) {
    node* hobbit = malloc(sizeof(node));
    hobbit->next = *head;
    hobbit->time = time;
    *head = hobbit;
}

/* remove a hobbit from a list */
void remv(node** head, int time) {
    if (*head == NULL) return;

    /* first one must change head */
    if ((*head)->time == time) {
        node* temp = *head;
        *head = (*head)->next;
        free(temp);
    } else {
        /* else we gotta search for it */
        node* prev = *head;
        node* curr = (*head)->next;
        while (curr) {
            if (curr->time == time) {
                prev->next = curr->next;
                free(curr);
                break;
            }
            prev = curr;
            curr = curr->next;
        }
    }
}

/* return the legnth of a list */
int len(node* head) {
    int size = 0;
    while (head) {
        size++;
        head = head->next;
    }
    return size;
}

/* find hobbit with the minimal or maximal time */
int superlative(node* head, int (*cmp)(int,int)) {
    /* if the list is empty, there is no best */
    if (!head) {
        return -1;
    }

    /* assume first one is best */
    int best = head->time;
    node* current = head->next;

    /* search rest of list for better one */
    while (current) {
        if (cmp(current->time, best)) {
            best = current->time;
        }
        current = current->next;
    }

    return best;
}

/* lt and gt make superlative function into min or max hobbit from list */
int lt(int a, int b) {
    return a < b;
}
int gt(int a, int b) {
    return a > b;
}

/* find max hobbit out of two */
int max(int a, int b) {
    return a > b ? a : b;
}

/* we write the output to this buffer, so that the total moves may be printed first */
char buffer[4096];

/* function to move a single hobbit from one side to the other */
int move(node** from, node** to, int (*cmp)(int, int), int newl) {
    /* find the hobbit from the one side */
    int hobbit = superlative(*from, cmp);

    /* move him to the other list */
    remv(from, hobbit);
    add(to, hobbit);

    /* append him to the buffer */
    sprintf(buffer + strlen(buffer), "%d", hobbit);

    /* print a new line or space for formatting and return */
    sprintf(buffer + strlen(buffer), "%c", newl ? '\n' : ' ');
    return hobbit;
}

/* simulate the solution to the problem */
int simulate(node* left, node* right, int total_time) {
    /* if the left side is empty, we're done */
    if (len(left) == 0) return total_time;

    /* if the left has 1 hobbit, move him and we're done */
    else if (len(left) == 1) {
        int h = move(&left, &right, &lt, 1);
        return total_time + h;
    }

    /* if the left has 2 hobbit, move them and we're done */
    else if (len(left) == 2) {
        /* move them and we're done */
        int h1 = move(&left, &right, &lt, 0);
        int h2 = move(&left, &right, &lt, 1);
        return total_time + max(h1, h2);
    }

    /* if there are three or more hobbits */
    else if (len(left) >= 3) {
        /* two fastest go left -> right */
        int f1 = move(&left, &right, &lt, 0);
        int f2 = move(&left, &right, &lt, 1);

        /* the fastest from right comes back left */
        int f3 = move(&right, &left, &lt, 1);

        /* the two slowest go left -> right */
        int s1 = move(&left, &right, &gt, 0);
        int s2 = move(&left, &right, &gt, 1);

        /* if there are still hobbits on the left, send fastest one back with lantern */
        int f4 = 0;
        if (len(left) > 0) {
            f4 = move(&right, &left, &lt, 1);
        }

        /* recurse again which will trigger the end */
        return simulate(left, right, total_time + max(f1, f2) + f3 + max(s1, s2) + f4);
    }
}


int main() {
    int n, i, temp;

    /* we keep track of all hobbits on both sides of the pass */
    node* left = NULL;
    node* right = NULL;

    /* read everyone into the left side */
    scanf("%d", &n);
    for (i = 0; i < n; i++) {
        scanf("%d", &temp);
        add(&left, temp);
    }

    /* simulate this getting the total amount of time */
    int time = simulate(left, right, 0);

    /* print the total time followed by the moves the algorithm made */
    printf("%d\n%s", time, buffer);

    return 0;
}

